@@ -1,6 +1,8 @@
 from warrant.api_resource import APIResource, WarrantException
-from warrant.warrant import Warrant, Subject
-from warrant.authz import Authz
+from warrant.list_result import ListResult
+from warrant.object import Object
+from warrant.warrant import Warrant, Subject, QueryResult
+from warrant.authz import Authz, CheckOp
 
 from warrant.feature import Feature
 from warrant.permission import Permission
@@ -10,7 +12,7 @@ from warrant.role import Role
 from warrant.user import User
 from warrant.tenant import Tenant
 
-__version__ = "2.0.0"
+__version__ = "3.0.0"
 
 api_key = ""
 api_endpoint = "https://api.warrant.dev"
